@@ -348,7 +348,7 @@ class MyCache(DistUpgrade.DistUpgradeCache.MyCache):
                                    "Available version: %s\n\n") % \
             (name, getattr(self[name].installed, "version", None),
              self[name].candidate.version)
-        if not self.CHANGELOG_ORIGIN in [o.origin for o in origins]:
+        if self.CHANGELOG_ORIGIN not in [o.origin for o in origins]:
             self._fetch_changelog_for_third_party_package(name)
             return
         # fixup epoch handling version
